@@ -1,7 +1,7 @@
 # ABSTRACT: Utilities for Monitoring ElasticSearch
 package App::ElasticSearch::Utilities;
 
-our $VERSION = '5.0'; # VERSION
+our $VERSION = '5.1'; # VERSION
 
 use strict;
 use warnings;
@@ -434,7 +434,7 @@ sub es_indices {
     else {
         my $res = es_request('_cat/indices', { uri_param => { h => 'index,status' } });
         foreach my $entry (@{ $res }) {
-            my ($index,$status) = @{ $entry }{qw(index status)};
+            my ($index,$status) = is_hashref($entry) ? @{ $entry }{qw(index status)} : split /\s+/, $entry;
             debug("Evaluating '$index'");
             if(!exists $args{_all}) {
                 # State Check Disqualification
@@ -802,7 +802,7 @@ App::ElasticSearch::Utilities - Utilities for Monitoring ElasticSearch
 
 =head1 VERSION
 
-version 5.0
+version 5.1
 
 =head1 SYNOPSIS
 
