@@ -2,7 +2,7 @@ package App::ElasticSearch::Utilities::HTTPRequest;
 # ABSTRACT: Allow for strange content elements for Elasticsearch APIs
 
 
-our $VERSION = '5.0'; # VERSION
+our $VERSION = '5.1'; # VERSION
 
 use strict;
 use warnings;
@@ -18,8 +18,6 @@ sub new {
     my $self = $class->SUPER::new(@_);
     $self->header('Accept' => 'application/json');
 
-    my ($pkg) = caller();
-    warn "You probably shouldn't being calling __PACKAGE__->new()" unless $pkg eq 'App::ElasticSearch::Utilities::Connection';
     return $self;
 }
 
@@ -62,7 +60,7 @@ App::ElasticSearch::Utilities::HTTPRequest - Allow for strange content elements
 
 =head1 VERSION
 
-version 5.0
+version 5.1
 
 =head1 SYNOPSIS
 
